@@ -240,6 +240,7 @@ class TileLayer(RasterLayer):
     detect_retina = Bool(False).tag(sync=True, o=True)
     no_wrap = Bool(False).tag(sync=True, o=True)
     tms = Bool(False).tag(sync=True, o=True)
+    show_loading = Bool(False).tag(sync=True)
 
     _load_callbacks = Instance(CallbackDispatcher, ())
 
@@ -392,10 +393,15 @@ class Polyline(Path):
     _model_name = Unicode('LeafletPolylineModel').tag(sync=True)
 
     locations = List().tag(sync=True)
+    scaling = Bool(True).tag(sync=True)
+    rotation = Bool(True).tag(sync=True)
+    uniform_scaling = Bool(False).tag(sync=True)
 
     # Options
     smooth_factor = Float(1.0).tag(sync=True, o=True)
     no_clip = Bool(True).tag(sync=True, o=True)
+    transform = Bool(False).tag(sync=True, o=True)
+    draggable = Bool(False).tag(sync=True, o=True)
 
 
 class Polygon(Polyline):
@@ -490,6 +496,7 @@ class GeoJSON(FeatureGroup):
     data = Dict().tag(sync=True)
     style = Dict().tag(sync=True)
     hover_style = Dict().tag(sync=True)
+    point_style = Dict().tag(sync=True)
 
     _click_callbacks = Instance(CallbackDispatcher, ())
     _hover_callbacks = Instance(CallbackDispatcher, ())
